--------------------------------------------------------------------------------------------
--|> FOCUS FRAME
--------------------------------------------------------------------------------------------

--> 📚 Libs
local RC = LibStub("LibRangeCheck-2.0")

--> ⬆ Upvalues
local C_NamePlate_GetNamePlateForUnit = C_NamePlate.GetNamePlateForUnit
local C_Timer_NewTicker = C_Timer.NewTicker
local UnitFactionGroup = UnitFactionGroup

--> Build Focus Frame
--------------------------------------
FTL_FOCUS_FRAME = FTL_FOCUS_FRAME or CreateFrame("Frame", "FTL_FOCUS_FRAME", UIParent)
FTL_FOCUS_FRAME:SetFrameStrata("DIALOG")
FTL_FOCUS_FRAME:SetPoint("CENTER", UIParent)
FTL_FOCUS_FRAME:SetSize(64, 64)
FTL_FOCUS_FRAME:SetAlpha(0)
--: Range Text
FTL_FOCUS_FRAME.RangeText = FTL_FOCUS_FRAME:CreateFontString(nil, "ARTWORK", nil)
FTL_FOCUS_FRAME.RangeText:SetFont("interface/addons/FTL/Media/Fonts/RobotoCondensed-Bold.ttf", 20, "OUTLINE")
FTL_FOCUS_FRAME.RangeText:SetPoint("BOTTOM", FTL_FOCUS_FRAME, "TOP", 0, 2)
FTL_FOCUS_FRAME.RangeText:SetJustifyH("CENTER")
FTL_FOCUS_FRAME.RangeText:SetShadowOffset(1, -1)
FTL_FOCUS_FRAME.RangeText:SetText("--")
FTL_FOCUS_FRAME.RangeText:SetDrawLayer("ARTWORK", 7)
--: Sheild Texture
FTL_FOCUS_FRAME.Sheild = FTL_FOCUS_FRAME:CreateTexture(nil, "ARTWORK", FTL_FOCUS_FRAME)
FTL_FOCUS_FRAME.Sheild:SetTexture("interface/addons/FTL/Media/Textures/FocusBackground_Shield.tga")
FTL_FOCUS_FRAME.Sheild:SetAllPoints()
FTL_FOCUS_FRAME.Sheild:SetAlpha(1)
FTL_FOCUS_FRAME.Sheild:SetBlendMode("BLEND")
FTL_FOCUS_FRAME.Faction = FTL_FOCUS_FRAME:CreateTexture(nil, "OVERLAY", FTL_FOCUS_FRAME)
FTL_FOCUS_FRAME.Faction:SetTexture("interface/addons/ftl/media/textures/unknown.tga")
FTL_FOCUS_FRAME.Faction:SetDrawLayer("OVERLAY", 2)
FTL_FOCUS_FRAME.Faction:SetPoint("TOPLEFT", FTL_FOCUS_FRAME, "TOPLEFT", 2, -2)
FTL_FOCUS_FRAME.Faction:SetPoint("BOTTOMRIGHT", FTL_FOCUS_FRAME, "BOTTOMRIGHT", -2, 2)
FTL_FOCUS_FRAME.Faction:SetVertexColor(1, 1, 1, 1)

--> Estimate Unit Range
--------------------------------------
local function EstimateUnitRange(unit)
    local minRange, maxRange = RC:GetRange(unit)
    if not minRange then
        return "--"
    elseif not maxRange then
        return minRange, "+"
    elseif minRange == 0 then
        return ""
    else
        return minRange
    end
end

--> Get estimated distance
--------------------------------------
local function UpdateDistance()
    local range, txt = EstimateUnitRange("focus")
    if range then
        if txt ~= nil then
            range = range .. txt
        end
        FTL_FOCUS_FRAME.RangeText:SetText(range)
    end
end

FTL_FOCUS_FRAME.Ticker = C_Timer_NewTicker(0.6, UpdateDistance)
FTL_FOCUS_FRAME.Ticker:Cancel()

--> Hide
--------------------------------------
function FTL_FOCUS_FRAME:Hide()
    if self.Ticker then
        self.Ticker:Cancel()
        self.Ticker = nil
    end
    self.RangeText:SetText("")
    self:SetAlpha(0)
    self:ClearAllPoints()
end

--> Show
--------------------------------------
function FTL_FOCUS_FRAME:Show()
    if C_NamePlate_GetNamePlateForUnit("focus") then
        self.Ticker = C_Timer_NewTicker(0.6, UpdateDistance)
        self:ClearAllPoints()
        self:SetPoint("BOTTOM", C_NamePlate_GetNamePlateForUnit("focus"), "CENTER", 0, 30)
        self:SetAlpha(1)
        local faction = UnitFactionGroup("focus")
        if faction == "Horde" then
            self.Faction:SetTexture("interface/addons/ftl/media/textures/horde.tga")
        elseif faction == "Alliance" then
            self.Faction:SetTexture("interface/addons/ftl/media/textures/alliance.tga")
        else
            self.Faction:SetTexture("interface/addons/ftl/media/textures/unknown.tga")
        end
    else
        self:Hide()
    end
end
