--|> LDB: (LibDataBroker, MiniMap Icon, Data Text)
----------------------------------------------------------------------------------------------------------
local ADDON_NAME, NS = ...

--: 🅰 Local String Constants
local addonTitle = "|cff3ef7b1FTL|r"
local disabledString = "|cfff40068Disabled|r"
local enabledString = "|cff4cf452Enabled|r"

--> Load LibDataBroker
----------------------------------------
local ldb = LibStub:GetLibrary("LibDataBroker-1.1", true)
if not ldb then
    NS.PrintAddonMessage("LibDataBroker not found!")
    return
end

--> MiniMap Icon: Create as LDB object
----------------------------------------
local MiniMapIcon =
    ldb:NewDataObject(
    ADDON_NAME,
    {
        type = "data source",
        text = "",
        icon = "Interface/Addons/FTL/Media/Icons/minimap.tga"
    }
)

--> MiniMap Icon: Build ToolTip
----------------------------------------
-- Creates a dynamic tooltip depending on current status of FTL
function MiniMapIcon.BuildToolTip()
    if FTL_CHARACTER_OPTIONS.Enabled == true then
        LibDBIconTooltip:AddDoubleLine(addonTitle, enabledString)
        LibDBIconTooltip:AddLine("Right-Click to disable")
    else
        LibDBIconTooltip:AddDoubleLine(addonTitle, disabledString)
        LibDBIconTooltip:AddLine("Right-Click to enable")
    end
end

--> MiniMap Icon: On Click
----------------------------------------
-- Toggle state, refresh tooltip, save variables
function MiniMapIcon.OnClick(_, button)
    if button == "RightButton" then
        if FTL_CHARACTER_OPTIONS.Enabled == true then
            NS.Disable()
        else
            NS.Enable()
        end
        LibDBIconTooltip:ClearLines()
        MiniMapIcon.BuildToolTip()
    end
end

--> MiniMap Icon: Show Tooltip
----------------------------------------
function MiniMapIcon.OnTooltipShow()
    MiniMapIcon.BuildToolTip()
end

--> Init
----------------------------------------
local LibDBIcon = LibStub("LibDBIcon-1.0", true)
local f = CreateFrame("Frame")
function MiniMapIcon.Init()
    if not LibDBIcon then
        return
    end
    LibDBIcon:Register(ADDON_NAME, MiniMapIcon, FTL_CHARACTER_OPTIONS.LDB)
    LibStub("LibDBIcon-1.0"):Show(ADDON_NAME)
    f:UnregisterEvent("PLAYER_LOGIN")
end

--> @E Player Login
----------------------------------------
-- tiny local watcher for the player login event
f:SetScript(
    "OnEvent",
    function()
        MiniMapIcon.Init()
        f = nil
    end
)
f:RegisterEvent("PLAYER_LOGIN")
